package com.ff.game.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ff.base.annotation.Log;
import com.ff.base.core.controller.BaseController;
import com.ff.base.core.domain.AjaxResult;
import com.ff.base.enums.BusinessType;
import com.ff.game.domain.GamePlatform;
import com.ff.game.service.IGamePlatformService;
import com.ff.base.utils.poi.ExcelUtil;
import com.ff.base.core.page.TableDataInfo;

/**
 * 平台管理Controller
 *
 * @author shi
 * @date 2025-02-10
 */
@RestController
@RequestMapping("/game/platform")
public class GamePlatformController extends BaseController
{
    @Autowired
    private IGamePlatformService gamePlatformService;

    /**
     * 查询平台管理列表
     */
    @PreAuthorize("@ss.hasPermi('game:platform:list')")
    @GetMapping("/list")
    public TableDataInfo list(GamePlatform gamePlatform)
    {
        startPage();
        List<GamePlatform> list = gamePlatformService.selectGamePlatformList(gamePlatform);
        return getDataTable(list);
    }

    /**
     * 导出平台管理列表
     */
    @PreAuthorize("@ss.hasPermi('game:platform:export')")
    @Log(title = "平台管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GamePlatform gamePlatform)
    {
        List<GamePlatform> list = gamePlatformService.selectGamePlatformList(gamePlatform);
        ExcelUtil<GamePlatform> util = new ExcelUtil<GamePlatform>(GamePlatform.class);
        util.exportExcel(response, list, "平台管理数据");
    }

    /**
     * 获取平台管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('game:platform:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gamePlatformService.selectGamePlatformById(id));
    }

    /**
     * 新增平台管理
     */
    @PreAuthorize("@ss.hasPermi('game:platform:add')")
    @Log(title = "平台管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GamePlatform gamePlatform)
    {
        return toAjax(gamePlatformService.insertGamePlatform(gamePlatform));
    }

    /**
     * 修改平台管理
     */
    @PreAuthorize("@ss.hasPermi('game:platform:edit')")
    @Log(title = "平台管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GamePlatform gamePlatform)
    {
        return toAjax(gamePlatformService.updateGamePlatform(gamePlatform));
    }

    /**
     * 删除平台管理
     */
    @PreAuthorize("@ss.hasPermi('game:platform:remove')")
    @Log(title = "平台管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gamePlatformService.deleteGamePlatformByIds(ids));
    }
}
